OrderWC class

Constructors

OrderWC({String? paymentMethod, String? paymentMethodTitle, bool? setPaid, String? status, String? currency, int? customerId, String? customerNote, int? parentId, List<MetaData>? metaData, List<FeeLines>? feeLines, List<CouponLines>? couponLines, Billing? billing, Shipping? shipping, List<LineItems>? lineItems, List<ShippingLines>? shippingLines, String? transactionId})
OrderWC.fromJson(Map<String, dynamic> json)

Properties

billing ↔ Billing?
getter/setter pair
couponLines ↔ List<CouponLines>?
getter/setter pair
currency ↔ String?
getter/setter pair
customerId ↔ int?
getter/setter pair
customerNote ↔ String?
getter/setter pair
feeLines ↔ List<FeeLines>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItems ↔ List<LineItems>?
getter/setter pair
metaData ↔ List<MetaData>?
getter/setter pair
parentId ↔ int?
getter/setter pair
paymentMethod ↔ String?
getter/setter pair
paymentMethodTitle ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setPaid ↔ bool?
getter/setter pair
shipping ↔ Shipping?
getter/setter pair
shippingLines ↔ List<ShippingLines>?
getter/setter pair
status ↔ String?
getter/setter pair
transactionId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited