Country class

Constructors

Country({String? code, String? name, List<State>? states, String? currencyCode, CurrencyPos? currencyPos, Sep? decimalSep, DimensionUnit? dimensionUnit, int? numDecimals, Sep? thousandSep, WeightUnit? weightUnit})
Country.fromJson(Map<String, dynamic> json)
factory

Properties

code ↔ String?
getter/setter pair
currencyCode ↔ String?
getter/setter pair
currencyPos ↔ CurrencyPos?
getter/setter pair
decimalSep ↔ Sep?
getter/setter pair
dimensionUnit ↔ DimensionUnit?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
numDecimals ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
states ↔ List<State>?
getter/setter pair
thousandSep ↔ Sep?
getter/setter pair
weightUnit ↔ WeightUnit?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited