Coupon class

Constructors

Coupon({int? id, String? code, String? amount, String? dateCreated, String? dateCreatedGmt, String? dateModified, String? dateModifiedGmt, String? discountType, String? description, String? dateExpires, String? dateExpiresGmt, int? usageCount, bool? individualUse, List<int>? productIds, List<int>? excludedProductIds, int? usageLimit, int? usageLimitPerUser, int? limitUsageToXItems, bool? freeShipping, List<int>? productCategories, List<int>? excludedProductCategories, bool? excludeSaleItems, String? minimumAmount, String? maximumAmount, List<String>? emailRestrictions, List<String>? usedBy, List<MetaData>? metaData, Links? links})
Coupon.fromJson(Map<String, dynamic> json)

Properties

amount ↔ String?
getter/setter pair
code ↔ String?
getter/setter pair
dateCreated ↔ String?
getter/setter pair
dateCreatedGmt ↔ String?
getter/setter pair
dateExpires ↔ String?
getter/setter pair
dateExpiresGmt ↔ String?
getter/setter pair
dateModified ↔ String?
getter/setter pair
dateModifiedGmt ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
discountType ↔ String?
getter/setter pair
emailRestrictions ↔ List<String>?
getter/setter pair
excludedProductCategories ↔ List<int>?
getter/setter pair
excludedProductIds ↔ List<int>?
getter/setter pair
excludeSaleItems ↔ bool?
getter/setter pair
freeShipping ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
individualUse ↔ bool?
getter/setter pair
limitUsageToXItems ↔ int?
getter/setter pair
getter/setter pair
maximumAmount ↔ String?
getter/setter pair
metaData ↔ List<MetaData>?
getter/setter pair
minimumAmount ↔ String?
getter/setter pair
productCategories ↔ List<int>?
getter/setter pair
productIds ↔ List<int>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usageCount ↔ int?
getter/setter pair
usageLimit ↔ int?
getter/setter pair
usageLimitPerUser ↔ int?
getter/setter pair
usedBy ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited