CustomerBatch class

Constructors

CustomerBatch({List<Customers>? create, List<Customers>? update, List<Customers>? delete})
CustomerBatch.fromJson(Map<String, dynamic> json)
factory

Properties

create ↔ List<Customers>?
getter/setter pair
delete ↔ List<Customers>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update ↔ List<Customers>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited