CustomerDownload class

Constructors

CustomerDownload({String? downloadId, String? downloadUrl, int? productId, String? productName, String? downloadName, int? orderId, String? orderKey, String? downloadsRemaining, String? accessExpires, String? accessExpiresGmt, File? file, Links? links})
CustomerDownload.fromJson(Map<String, dynamic> json)

Properties

accessExpires ↔ String?
getter/setter pair
accessExpiresGmt ↔ String?
getter/setter pair
downloadId ↔ String?
getter/setter pair
downloadName ↔ String?
getter/setter pair
downloadsRemaining ↔ String?
getter/setter pair
downloadUrl ↔ String?
getter/setter pair
file ↔ File?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
orderId ↔ int?
getter/setter pair
orderKey ↔ String?
getter/setter pair
productId ↔ int?
getter/setter pair
productName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited