LineItems class

Constructors

LineItems({int? id, String? name, int? productId, int? variationId, int? quantity, String? taxClass, String? subtotal, String? subtotalTax, String? total, String? totalTax, List<Taxes>? taxes, List<MetaData>? metaData, String? sku, String? price})
LineItems.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
metaData ↔ List<MetaData>?
getter/setter pair
name ↔ String?
getter/setter pair
price ↔ String?
getter/setter pair
productId ↔ int?
getter/setter pair
quantity ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
getter/setter pair
subtotal ↔ String?
getter/setter pair
subtotalTax ↔ String?
getter/setter pair
taxClass ↔ String?
getter/setter pair
taxes ↔ List<Taxes>?
getter/setter pair
total ↔ String?
getter/setter pair
totalTax ↔ String?
getter/setter pair
variationId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited