OrderBatch class

Constructors

OrderBatch({List<Orders>? create, List<Orders>? update, List<Delete>? delete})
OrderBatch.fromJson(Map<String, dynamic> json)
factory

Properties

create ↔ List<Orders>?
getter/setter pair
delete ↔ List<Delete>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update ↔ List<Orders>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited