ShippingLine class

Constructors

ShippingLine({int? id, String? methodTitle, String? methodId, String? total, String? totalTax, List? taxes, List<MetaDatum>? metaData})
ShippingLine.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
metaData ↔ List<MetaDatum>?
getter/setter pair
methodId ↔ String?
getter/setter pair
methodTitle ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxes ↔ List?
getter/setter pair
total ↔ String?
getter/setter pair
totalTax ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited