PaymentGateWay class

Constructors

PaymentGateWay({String? id, String? title, String? description, String? order, bool? enabled, String? methodTitle, String? methodDescription, List<String>? methodSupports, Settings? settings, Links? links})
PaymentGateWay.fromJson(Map<String, dynamic> json)
factory

Properties

description ↔ String?
getter/setter pair
enabled ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
getter/setter pair
methodDescription ↔ String?
getter/setter pair
methodSupports ↔ List<String>?
getter/setter pair
methodTitle ↔ String?
getter/setter pair
order ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ Settings?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited