Title class

Constructors

Title({String? id, String? label, String? description, Type? type, String? value, String? titleDefault, String? tip, Placeholder? placeholder, TitleOptions? options})
Title.fromJson(Map<String, dynamic> json)
factory

Properties

description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
options ↔ TitleOptions?
getter/setter pair
placeholder ↔ Placeholder?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tip ↔ String?
getter/setter pair
titleDefault ↔ String?
getter/setter pair
type ↔ Type?
getter/setter pair
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited