Product class

Constructors

Product(int? id, String? name, String? slug, String? permalink, String? type, String? status, bool? featured, String? catalogVisibility, String? description, String? shortDescription, String? sku, String? price, String? regularPrice, String? salePrice, String? priceHtml, bool? onSale, bool? purchasable, int? totalSales, bool? virtual, bool? downloadable, List<Download> downloads, int? downloadLimit, int? downloadExpiry, String? externalUrl, String? buttonText, String? taxStatus, String? taxClass, bool? manageStock, int? stockQuantity, String? stockStatus, String? backorders, bool? backordersAllowed, bool? backordered, bool? soldIndividually, String? weight, Dimension dimensions, bool? shippingRequired, bool? shippingTaxable, String? shippingClass, int? shippingClassId, bool? reviewsAllowed, String? averageRating, int? ratingCount, List<int>? relatedIds, List<int>? upsellIds, List<int>? crossSellIds, int? parentId, String? purchaseNote, List<Category> categories, List<Tag> tags, List<Image> images, List<Attribute> attributes, List<DefaultAttribute> defaultAttributes, List<int>? variations, List<int>? groupedProducts, int? menuOrder, List<MetaData> metaData, String? dateCreated, String? dateCreatedGMT)
Product.fromJson(Map<String, dynamic> json)

Properties

attributes → List<Attribute>
final
averageRating → String?
final
backordered → bool?
final
backorders → String?
final
backordersAllowed → bool?
final
buttonText → String?
final
catalogVisibility → String?
final
categories → List<Category>
final
crossSellIds → List<int>?
final
dateCreated → String?
final
dateCreatedGMT → String?
final
defaultAttributes → List<DefaultAttribute>
final
description → String?
final
dimensions → Dimension
final
downloadable → bool?
final
downloadExpiry → int?
final
downloadLimit → int?
final
downloads → List<Download>
final
externalUrl → String?
final
final
groupedProducts → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
images → List<Image>
final
manageStock → bool?
final
final
metaData → List<MetaData>
final
name → String?
final
onSale → bool?
final
parentId → int?
final
final
price → String?
final
priceHtml → String?
final
purchasable → bool?
final
purchaseNote → String?
final
ratingCount → int?
final
regularPrice → String?
final
relatedIds → List<int>?
final
reviewsAllowed → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salePrice → String?
final
shippingClass → String?
final
shippingClassId → int?
final
shippingRequired → bool?
final
shippingTaxable → bool?
final
shortDescription → String?
final
sku → String?
final
slug → String?
final
soldIndividually → bool?
final
status → String?
final
stockQuantity → int?
final
stockStatus → String?
final
tags → List<Tag>
final
taxClass → String?
final
taxStatus → String?
final
totalSales → int?
final
type → String?
final
upsellIds → List<int>?
final
variations → List<int>?
final
virtual → bool?
final
weight → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited