Attribute class

Constructors

Attribute({int? id, String? name, int? position, bool? visible, bool? variation, List<String>? options})
Attribute.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
options ↔ List<String>?
getter/setter pair
position ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variation ↔ bool?
getter/setter pair
visible ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited