ActivePlugin class

Constructors

ActivePlugin({String? plugin, String? name, String? version, String? versionLatest, String? url, String? authorName, String? authorUrl, bool? networkActivated})
ActivePlugin.fromJson(Map<String, dynamic> json)
factory

Properties

authorName ↔ String?
getter/setter pair
authorUrl ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
networkActivated ↔ bool?
getter/setter pair
plugin ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair
versionLatest ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited