Database class

Constructors

Database({String? wcDatabaseVersion, String? databasePrefix, String? maxmindGeoipDatabase, DatabaseTables? databaseTables, DatabaseSize? databaseSize})
Database.fromJson(Map<String, dynamic> json)
factory

Properties

databasePrefix ↔ String?
getter/setter pair
databaseSize ↔ DatabaseSize?
getter/setter pair
databaseTables ↔ DatabaseTables?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxmindGeoipDatabase ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wcDatabaseVersion ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited