ProductVisibilityTerms class

Constructors

ProductVisibilityTerms({String? excludeFromCatalog, String? excludeFromSearch, String? featured, String? outofstock, String? rated1, String? rated2, String? rated3, String? rated4, String? rated5})
ProductVisibilityTerms.fromJson(Map<String, dynamic> json)
factory

Properties

excludeFromCatalog ↔ String?
getter/setter pair
excludeFromSearch ↔ String?
getter/setter pair
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outofstock ↔ String?
getter/setter pair
rated1 ↔ String?
getter/setter pair
rated2 ↔ String?
getter/setter pair
rated3 ↔ String?
getter/setter pair
rated4 ↔ String?
getter/setter pair
rated5 ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited