Settings class

Constructors

Settings({bool? apiEnabled, bool? forceSsl, String? currency, String? currencySymbol, String? currencyPosition, String? thousandSeparator, String? decimalSeparator, int? numberOfDecimals, bool? geolocationEnabled, Taxonomies? taxonomies, ProductVisibilityTerms? productVisibilityTerms})
Settings.fromJson(Map<String, dynamic> json)
factory

Properties

apiEnabled ↔ bool?
getter/setter pair
currency ↔ String?
getter/setter pair
currencyPosition ↔ String?
getter/setter pair
currencySymbol ↔ String?
getter/setter pair
decimalSeparator ↔ String?
getter/setter pair
forceSsl ↔ bool?
getter/setter pair
geolocationEnabled ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numberOfDecimals ↔ int?
getter/setter pair
productVisibilityTerms ↔ ProductVisibilityTerms?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxonomies ↔ Taxonomies?
getter/setter pair
thousandSeparator ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited