SystemStatus class

Constructors

SystemStatus({Environment? environment, Database? database, List<ActivePlugin>? activePlugins, Theme? theme, Settings? settings, Security? security, List<Page>? pages})
SystemStatus.fromJson(Map<String, dynamic> json)
factory

Properties

activePlugins ↔ List<ActivePlugin>?
getter/setter pair
database ↔ Database?
getter/setter pair
environment ↔ Environment?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pages ↔ List<Page>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security ↔ Security?
getter/setter pair
settings ↔ Settings?
getter/setter pair
theme ↔ Theme?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited