TaxRate class

Constructors

TaxRate({int? id, String? country, String? state, String? postcode, String? city, String? rate, String? name, int? priority, bool? compound, bool? shipping, int? order, String? taxClass, Links? links})
TaxRate.fromJson(Map<String, dynamic> json)

Properties

city ↔ String?
getter/setter pair
compound ↔ bool?
getter/setter pair
country ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
getter/setter pair
name ↔ String?
getter/setter pair
order ↔ int?
getter/setter pair
postcode ↔ String?
getter/setter pair
priority ↔ int?
getter/setter pair
rate ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipping ↔ bool?
getter/setter pair
state ↔ String?
getter/setter pair
taxClass ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited